@@ -1,5 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nill; c-basic-offset: 8 -*- */
 /*
+ * Copyright (C) 2004-2005 Imendio AB
  * Copyright (C) 2002-2003 CodeFactory AB
  * Copyright (C) 2002-2003 Richard Hult <richard@imendio.com>
  * Copyright (C) 2002 Mikael Hallendal <micke@imendio.com>
@@ -28,7 +29,7 @@
 #include <stdlib.h>
 #include "mrp-private.h"
 #include "mrp-error.h"
-#include "mrp-intl.h"
+#include <glib/gi18n.h>
 #include "mrp-task.h"
 #include "mrp-resource.h"
 #include "mrp-group.h"
@@ -212,6 +213,7 @@ old_xml_read_task (MrpParser *parser, xmlNodePtr tree, MrpTask *parent)
 	MrpTask       *task;
 	MrpConstraint  constraint;
 	guint          percent_complete = 0;
+	gint          priority = 0;
 	gchar         *note;
 	gint           duration, work;
 	gboolean       got_constraint = FALSE;
@@ -227,9 +229,10 @@ old_xml_read_task (MrpParser *parser, xmlNodePtr tree, MrpTask *parent)
 	note = old_xml_get_string (tree, "note");
 	id = old_xml_get_int (tree, "id");
 	percent_complete = old_xml_get_int (tree, "percent-complete");
+	priority = old_xml_get_int (tree, "priority");
 	type = old_xml_get_task_type (tree, "type");
 	sched = old_xml_get_task_sched (tree, "scheduling");
-	
+
 	if (parser->version == 1) {
 		start = old_xml_get_date (tree, "start");
 		end = old_xml_get_date (tree, "end");
@@ -250,6 +253,7 @@ old_xml_read_task (MrpParser *parser, xmlNodePtr tree, MrpTask *parent)
 				     "name", name,
 				     "duration", duration,
 				     "percent_complete", percent_complete,
+				     "priority", priority,
 				     "note", note,
 				     NULL);
 	} else {
@@ -284,6 +288,7 @@ old_xml_read_task (MrpParser *parser, xmlNodePtr tree, MrpTask *parent)
 				     "work", work,
 				     "duration", duration,
 				     "percent_complete", percent_complete,
+				     "priority", priority,
 				     "note", note,
 				     NULL);
 	}
@@ -321,6 +326,14 @@ old_xml_read_task (MrpParser *parser, xmlNodePtr tree, MrpTask *parent)
 	
 	for (tasks = tree->children; tasks; tasks = tasks->next) {
 		if (!strcmp (tasks->name, "task")) {
+			/* Silently correct old milestones with children to
+			 * normal tasks.
+			 */
+			if (type == MRP_TASK_TYPE_MILESTONE) {
+				type = MRP_TASK_TYPE_NORMAL;
+				g_object_set (task, "type", type, NULL);
+			}
+			
 			old_xml_read_task (parser, tasks, task);
 		}
 		else if (!strcmp (tasks->name, "predecessors")) {
@@ -346,7 +359,8 @@ old_xml_read_resource (MrpParser *parser, xmlNodePtr tree)
 	xmlNodePtr   child;
 	gint         id;
 	gint         type;
-	gchar       *name, *email;
+	gchar       *name, *short_name, *email;
+	gchar       *note;
 	gint         gid;
 	gint         units;
 	gfloat       std_rate; /*, ovt_rate;*/
@@ -362,6 +376,7 @@ old_xml_read_resource (MrpParser *parser, xmlNodePtr tree)
 
 	id          = old_xml_get_int (tree, "id");
 	name        = old_xml_get_string (tree, "name");
+	short_name  = old_xml_get_string (tree, "short-name");
 	gid         = old_xml_get_int (tree, "group");
 	type        = old_xml_get_int (tree, "type");
 	units       = old_xml_get_int (tree, "units");
@@ -369,21 +384,32 @@ old_xml_read_resource (MrpParser *parser, xmlNodePtr tree)
 	/*ovt_rate = old_xml_get_float (tree, "ovt-rate");*/
 	email       = old_xml_get_string (tree, "email");
 	calendar_id = old_xml_get_int (tree, "calendar");
+        note        = old_xml_get_string (tree, "note");
 
+	if (short_name == NULL) {
+		short_name = g_strdup ("");
+	}
+	
 	if (email == NULL) {
 		email = g_strdup ("");
 	}
 
+	if (note == NULL) {
+		note = g_strdup ("");
+	}
+
 	group = g_hash_table_lookup (parser->group_hash, GINT_TO_POINTER (gid));
 	calendar = g_hash_table_lookup (parser->calendar_hash, GINT_TO_POINTER (calendar_id));
 		
 	resource = g_object_new (MRP_TYPE_RESOURCE,
 				 "name", name,
+				 "short_name", short_name,
 				 "type", type,
 				 "group", group,
 				 "units", units,
 				 "email", email,
 				 "calendar", calendar,
+				 "note", note,
 				 NULL);
 
 	/* These are cost custom properties */
@@ -408,6 +434,8 @@ old_xml_read_resource (MrpParser *parser, xmlNodePtr tree)
 	
 	g_free (name);
 	g_free (email);
+	g_free (short_name);
+	g_free (note);
 }
 
 static void
@@ -470,11 +498,13 @@ old_xml_read_assignment (MrpParser *parser, xmlNodePtr tree)
 					GINT_TO_POINTER (resource_id));
 	
 	if (!task) {
-		g_print ("NO TASK FROM HASH\n");
+		g_warning ("Corrupt file? Task %d not found in hash.", task_id);
+		goto fail;
 	}
 
 	if (!resource) {
-		g_print ("NO RESOURCE FROM HASH\n");
+		g_warning ("Corrupt file? Resource %d not found in hash.", resource_id);
+		goto fail;
 	}
 
 	assignment = g_object_new (MRP_TYPE_ASSIGNMENT,
@@ -484,6 +514,9 @@ old_xml_read_assignment (MrpParser *parser, xmlNodePtr tree)
 				   NULL);
 
 	parser->assignments = g_list_prepend (parser->assignments, assignment);
+
+ fail:
+	; /* Avoid gcc warning. */
 }
 
 static void
@@ -622,7 +655,7 @@ old_xml_read_overridden_day (MrpParser   *parser,
 	
 	if (sscanf (xml_str, "%04d%02d%02d", &y, &m, &d) == 3) {
 		date = mrp_time_compose (y, m, d, 0, 0, 0);
-		mrp_calendar_set_days (calendar, date, mrp_day, -1);		
+		mrp_calendar_set_days (calendar, date, mrp_day, (mrptime) -1);		
 	} else {
 		g_warning ("Invalid time format for overridden day.");
 	}
@@ -845,13 +878,24 @@ old_xml_read_property_specs (MrpParser *parser)
 
 		type = old_xml_property_type_from_string (type_str);
 		
-		/* #534 */
 		property = mrp_property_new (name,
 					     type,
 					     label,
 					     description,
 					     TRUE);
 
+		/* If we could't create the property, this means that we are
+		 * trying to use a name that is already taken.
+		 */
+		if (!property) {
+			g_free (name);
+			g_free (type_str);
+			g_free (owner_str);
+			g_free (label);
+			g_free (description);
+			continue;
+		}
+		
 		if (!strcmp (owner_str, "task")) {
 			owner = MRP_TYPE_TASK;
 		}
@@ -1014,12 +1058,13 @@ old_xml_read_project (MrpParser *parser)
 		for (groups = child->children; groups; groups = groups->next) {
 			old_xml_read_group (parser, groups); 
 		}
+
+		/* Gah, why underscore?! */
+		gid = old_xml_get_int (child, "default_group");
+		parser->default_group = g_hash_table_lookup (parser->group_hash,
+							     GINT_TO_POINTER (gid));
 	}
 	
-	gid = old_xml_get_int (child, "default_group");
-        parser->default_group = g_hash_table_lookup (parser->group_hash,
-						     GINT_TO_POINTER (gid));
-
 	/* Load resources. */
  	child = old_xml_search_child (parser->doc->children, "resources"); 
 	if (child != NULL) {
@@ -1329,14 +1374,21 @@ old_xml_set_property_from_node (MrpProject *project,
 
 	str = old_xml_get_string (node, "value");
 
+	/* Check if we have the property first. This is needed both to be robust
+	 * against broken input.
+	 */
+	if (!mrp_project_has_property (project,
+				       G_OBJECT_TYPE (object),
+				       name)) {
+		g_free (name);
+		g_free (str);
+		return;
+	}
+	
 	property = mrp_project_get_property (project,
 					     name,
 					     G_OBJECT_TYPE (object));
 
-	if (property == NULL) {
-		return;
-	}
-	
 	type = mrp_property_get_property_type (property);
 
 	switch (type) {
@@ -1447,6 +1499,8 @@ mrp_old_xml_parse (MrpProject *project, xmlDoc *doc, GError **error)
         task_manager = imrp_project_get_task_manager (project);
         mrp_task_manager_set_root (task_manager, parser.root_task);
 
+	parser.project_start = mrp_time_align_day (parser.project_start);
+	
 	g_object_set (project,
                       "project-start", parser.project_start,
                       "default-group", parser.default_group,
@@ -1475,8 +1529,6 @@ mrp_old_xml_parse (MrpProject *project, xmlDoc *doc, GError **error)
         g_list_free (parser.assignments);
         g_list_free (parser.resources);
 	
-/* 	module->resources = parser.resources; */
-	
 	return TRUE;
 }
 
